==> openshift-model-machineconfig-5.10.1-sources.jar: io/fabric8/openshift/api/model/machineconfig/v1/ContainerRuntimeConfigurationFluentImpl.java <==
package io.fabric8.openshift.api.model.machineconfig.v1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import io.fabric8.kubernetes.api.model.Quantity;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class ContainerRuntimeConfigurationFluentImpl<A extends io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfigurationFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfigurationFluent<A>{
  public ContainerRuntimeConfigurationFluentImpl() {
  }
  public ContainerRuntimeConfigurationFluentImpl(io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfiguration instance) {
    this.withLogLevel(instance.getLogLevel()); 
    this.withLogSizeMax(instance.getLogSizeMax()); 
    this.withOverlaySize(instance.getOverlaySize()); 
    this.withPidsLimit(instance.getPidsLimit()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String logLevel;
  private io.fabric8.kubernetes.api.model.Quantity logSizeMax;
  private io.fabric8.kubernetes.api.model.Quantity overlaySize;
  private java.lang.Long pidsLimit;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getLogLevel() {
    return this.logLevel;
  }
  public A withLogLevel(java.lang.String logLevel) {
    this.logLevel=logLevel; return (A) this;
  }
  public java.lang.Boolean hasLogLevel() {
    return this.logLevel != null;
  }
  
  /**
   * Method is deprecated. use withLogLevel instead.
   */
  @java.lang.Deprecated
  public A withNewLogLevel(java.lang.String arg0) {
    return (A)withLogLevel(new String(arg0));
  }
  public io.fabric8.kubernetes.api.model.Quantity getLogSizeMax() {
    return this.logSizeMax;
  }
  public A withLogSizeMax(io.fabric8.kubernetes.api.model.Quantity logSizeMax) {
    this.logSizeMax=logSizeMax; return (A) this;
  }
  public java.lang.Boolean hasLogSizeMax() {
    return this.logSizeMax != null;
  }
  public A withNewLogSizeMax(java.lang.String amount,java.lang.String format) {
    return (A)withLogSizeMax(new Quantity(amount, format));
  }
  public A withNewLogSizeMax(java.lang.String amount) {
    return (A)withLogSizeMax(new Quantity(amount));
  }
  public io.fabric8.kubernetes.api.model.Quantity getOverlaySize() {
    return this.overlaySize;
  }
  public A withOverlaySize(io.fabric8.kubernetes.api.model.Quantity overlaySize) {
    this.overlaySize=overlaySize; return (A) this;
  }
  public java.lang.Boolean hasOverlaySize() {
    return this.overlaySize != null;
  }
  public A withNewOverlaySize(java.lang.String amount,java.lang.String format) {
    return (A)withOverlaySize(new Quantity(amount, format));
  }
  public A withNewOverlaySize(java.lang.String amount) {
    return (A)withOverlaySize(new Quantity(amount));
  }
  public java.lang.Long getPidsLimit() {
    return this.pidsLimit;
  }
  public A withPidsLimit(java.lang.Long pidsLimit) {
    this.pidsLimit=pidsLimit; return (A) this;
  }
  public java.lang.Boolean hasPidsLimit() {
    return this.pidsLimit != null;
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ContainerRuntimeConfigurationFluentImpl that = (ContainerRuntimeConfigurationFluentImpl) o;
    if (logLevel != null ? !logLevel.equals(that.logLevel) :that.logLevel != null) return false;
    if (logSizeMax != null ? !logSizeMax.equals(that.logSizeMax) :that.logSizeMax != null) return false;
    if (overlaySize != null ? !overlaySize.equals(that.overlaySize) :that.overlaySize != null) return false;
    if (pidsLimit != null ? !pidsLimit.equals(that.pidsLimit) :that.pidsLimit != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(logLevel,  logSizeMax,  overlaySize,  pidsLimit,  additionalProperties,  super.hashCode());
  }
  
}

==> openshift-model-machineconfig-5.12.3-sources.jar: io/fabric8/openshift/api/model/machineconfig/v1/ContainerRuntimeConfigurationFluentImpl.java <==
package io.fabric8.openshift.api.model.machineconfig.v1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import io.fabric8.kubernetes.api.model.Quantity;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class ContainerRuntimeConfigurationFluentImpl<A extends io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfigurationFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfigurationFluent<A>{
  public ContainerRuntimeConfigurationFluentImpl() {
  }
  public ContainerRuntimeConfigurationFluentImpl(io.fabric8.openshift.api.model.machineconfig.v1.ContainerRuntimeConfiguration instance) {
    this.withLogLevel(instance.getLogLevel()); 
    this.withLogSizeMax(instance.getLogSizeMax()); 
    this.withOverlaySize(instance.getOverlaySize()); 
    this.withPidsLimit(instance.getPidsLimit()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String logLevel;
  private io.fabric8.kubernetes.api.model.Quantity logSizeMax;
  private io.fabric8.kubernetes.api.model.Quantity overlaySize;
  private java.lang.Long pidsLimit;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getLogLevel() {
    return this.logLevel;
  }
  public A withLogLevel(java.lang.String logLevel) {
    this.logLevel=logLevel; return (A) this;
  }
  public java.lang.Boolean hasLogLevel() {
    return this.logLevel != null;
  }
  
  /**
   * Method is deprecated. use withLogLevel instead.
   */
  @java.lang.Deprecated
  public A withNewLogLevel(java.lang.String arg0) {
    return (A)withLogLevel(new String(arg0));
  }
  public io.fabric8.kubernetes.api.model.Quantity getLogSizeMax() {
    return this.logSizeMax;
  }
  public A withLogSizeMax(io.fabric8.kubernetes.api.model.Quantity logSizeMax) {
    this.logSizeMax=logSizeMax; return (A) this;
  }
  public java.lang.Boolean hasLogSizeMax() {
    return this.logSizeMax != null;
  }
  public A withNewLogSizeMax(java.lang.String amount,java.lang.String format) {
    return (A)withLogSizeMax(new Quantity(amount, format));
  }
  public A withNewLogSizeMax(java.lang.String amount) {
    return (A)withLogSizeMax(new Quantity(amount));
  }
  public io.fabric8.kubernetes.api.model.Quantity getOverlaySize() {
    return this.overlaySize;
  }
  public A withOverlaySize(io.fabric8.kubernetes.api.model.Quantity overlaySize) {
    this.overlaySize=overlaySize; return (A) this;
  }
  public java.lang.Boolean hasOverlaySize() {
    return this.overlaySize != null;
  }
  public A withNewOverlaySize(java.lang.String amount,java.lang.String format) {
    return (A)withOverlaySize(new Quantity(amount, format));
  }
  public A withNewOverlaySize(java.lang.String amount) {
    return (A)withOverlaySize(new Quantity(amount));
  }
  public java.lang.Long getPidsLimit() {
    return this.pidsLimit;
  }
  public A withPidsLimit(java.lang.Long pidsLimit) {
    this.pidsLimit=pidsLimit; return (A) this;
  }
  public java.lang.Boolean hasPidsLimit() {
    return this.pidsLimit != null;
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ContainerRuntimeConfigurationFluentImpl that = (ContainerRuntimeConfigurationFluentImpl) o;
    if (logLevel != null ? !logLevel.equals(that.logLevel) :that.logLevel != null) return false;
    if (logSizeMax != null ? !logSizeMax.equals(that.logSizeMax) :that.logSizeMax != null) return false;
    if (overlaySize != null ? !overlaySize.equals(that.overlaySize) :that.overlaySize != null) return false;
    if (pidsLimit != null ? !pidsLimit.equals(that.pidsLimit) :that.pidsLimit != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(logLevel,  logSizeMax,  overlaySize,  pidsLimit,  additionalProperties,  super.hashCode());
  }
  
}
